#
# AFS Server management toolkit: Rename an entry
# -*- coding: utf-8 -*-
#

__copyright__ = """
Copyright (C) 2014 Red Hat, Inc. All Rights Reserved.
Written by David Howells (dhowells@redhat.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public Licence version 2 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public Licence
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
"""

from kafs.argparse import *
from kafs.lib.output import *
import kafs.rpc as rpc
import sys

help = "Change the name of a Protection Database entry"

command_arguments = [
    [ "oldname",        get_string,             "rs",         "<old name>" ],
    [ "newname",        get_string,             "rs",         "<new name>" ],
    [ "cell",           get_cell,               "os",         "<cell name>" ],
    [ "noauth",         get_auth,               "fn" ],
    [ "localauth",      get_auth,               "fn" ],
    [ "verbose",        get_verbose,            "fn" ],
    [ "encrypt",        get_dummy,              "fn" ],
    [ "force",          get_dummy,              "fn" ],
]

cant_combine_arguments = [
    ( "cell",           "localauth" ),
    ( "noauth",         "localauth" ),
]

argument_size_limits = {
    "oldname"           : rpc.PR_MAXNAMELEN,
    "newname"           : rpc.PR_MAXNAMELEN,
}

description = r"""
Change the name of a Protection Database entry
"""

def main(params):
    exitcode = 0
    cell = params["cell"]
    prcache = cell.get_prcache(params)

    newname = params["newname"]
    uid = prcache.name_or_id_to_id(params["oldname"])
    if uid == None:
        error("User or group doesn't exist ; unable to change name of ",
              params["oldname"], " to ", newname, "\n")
        return

    try:
        verbose("Renaming ", uid, " to ", newname, "\n")
        ret = cell.call_pt_server(params, rpc.PR_ChangeEntry, uid, newname, 0, 0)
        prcache.evict_id(uid)
        prcache.evict_groups()
    except rpc.AbortPREXIST:
        error("Entry for name already exists ; unable to change name of ",
              prcache.id_to_name(uid), " to ", newname, "\n")
    except rpc.AbortPRNOENT:
        error("User or group doesn't exist ; unable to change name of ",
              uid, " to ", newname, "\n")

